window.Gleam.initSearch([{"doc":"mat","title":"mat","content":"# mat\n\n*It&#39;s easy for `mat` to format strings!*\n\n[![Package Version](https://img.shields.io/hexpm/v/mat)](https://hex.pm/packages/mat)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/mat/)\n\n`mat` is a gleam library for simple string formatting.\n\nIt&#39;s goals is easy and ergonomic formatting of any values.\n\n```sh\ngleam add mat\n```\n\n```gleam\nimport mat\nimport gleam/io\n\npub fn main() {\n  mat.format2(&quot;This is hello from {}! The answer is {}&quot;, &quot;Mat&quot;, 42)\n  |&gt; io.println\n}\n```\nIt formats any variable type: `String`, `Int`, `List`, your own types, etc.!\n\n`mat` is also fault-tolerant. It will do it&#39;s best with what it&#39;s given.\n\nToo many variables? Ignore the rest.\nNot enough variables? Leave the placeholders in.\n\n\nThis means that you don&#39;t have to handle any `Result`s.\nThis makes it convenient for prototyping or for cases where you don&#39;t care about the output that much (for example logs)\n\nIf you&#39;re looking for more robust formatting, with type-safety, check out &lt;https://github.com/mooreryan/gleam_fmt&gt;.\n\n## Limitations\n\nBecause `mat` is just a gleam library, there are some limitations on the ergonomics front.\n\nSince you can&#39;t have heterogeneous lists or a variable amount of arguments, you have to either:\n\n1. Use correct function, e.g. `format3` if you have 3 variables\n2. Convert all your arguments to `dynamic`s and use that with `format_list`\n\nOf course, if all your variables are of the same type, you can simple use `format_list` with a list of that type.\n\nFunctions are currently rendered as `&lt;function&gt;`, because I haven&#39;t yet found a way to get information about a function.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/mat&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n","url":"index.html"},{"doc":"mat","title":"format1","content":"pub fn format1(template: String, a: a) -&gt; String\n Formats the `template` string, replacing the first occurrence of `&quot;{}&quot;`\n with a display-value of `a`\nSynonyms:\nmat.format1\nmat format1","url":"mat.html#format1"},{"doc":"mat","title":"format2","content":"pub fn format2(template: String, a: a, b: b) -&gt; String\n Formats the `template` string, replacing the first occurrence of `&quot;{}&quot;`\n with a display-value of `a`, second `&quot;{}&quot;` with `b`\nSynonyms:\nmat.format2\nmat format2","url":"mat.html#format2"},{"doc":"mat","title":"format3","content":"pub fn format3(template: String, a: a, b: b, c: c) -&gt; String\n Formats the `template` string, replacing the first occurrence of `&quot;{}&quot;`\n with a display-value of `a`, second `&quot;{}&quot;` with `b`, etc.\nSynonyms:\nmat.format3\nmat format3","url":"mat.html#format3"},{"doc":"mat","title":"format4","content":"pub fn format4(\n  template: String,\n  a: a,\n  b: b,\n  c: c,\n  d: d,\n) -&gt; String\n Formats the `template` string, replacing the first occurrence of `&quot;{}&quot;`\n with a display-value of `a`, second `&quot;{}&quot;` with `b`, etc.\nSynonyms:\nmat.format4\nmat format4","url":"mat.html#format4"},{"doc":"mat","title":"format5","content":"pub fn format5(\n  template: String,\n  a: a,\n  b: b,\n  c: c,\n  d: d,\n  e: e,\n) -&gt; String\n Formats the `template` string, replacing the first occurrence of `&quot;{}&quot;`\n with a display-value of `a`, second `&quot;{}&quot;` with `b`, etc.\nSynonyms:\nmat.format5\nmat format5","url":"mat.html#format5"},{"doc":"mat","title":"format_list","content":"pub fn format_list(template: String, values: List(a)) -&gt; String\n Formats the `template` string, replacing each `&quot;{}&quot;`\n with the display-values of consecutive elements of `values`.\n\n ---\n Excessive elements of `values` are ignored.\n Placeholders (`&quot;{}&quot;`) which don&#39;t have a corresponding element are left as-is.\nSynonyms:\nmat.format_list\nmat format_list","url":"mat.html#format_list"},{"doc":"mat","title":"mat","content":"","url":"mat.html"}]);